@@ -18,7 +18,6 @@ from nxtensor.core.types import VariableId, LabelId, Period
 
 import nxtensor.utils.hdf5_utils as hu
 import nxtensor.utils.naming_utils as nu
-import nxtensor.utils.csv_utils as cu
 import nxtensor.utils.db_utils as du
 
 from multiprocessing import Pool
@@ -30,7 +29,6 @@ import os.path as path
 
 from nxtensor.exceptions import ConfigurationError
 from nxtensor.extraction import ExtractionConfig
-from nxtensor.utils.tensor_dimensions import TensorDimension
 
 import random
 
@@ -131,7 +129,6 @@ def channel_building(variable_id: VariableId, channel_output_dir_path: str,
     channel_data, channel_metadata, dataset_indexes = \
         assembly.concatenate_data_compute_dataset_indexes(periods, label_ids, total_number_images, block_data_structure,
                                                           ratios)
-    channel_data, mean, scale = assembly.normalize_scale(channel_data, True, True)
     os.makedirs(channel_output_dir_path, exist_ok=True)
     # Split the data and metadata according to the user's dataset specifications.
     for dataset_name, indexes in dataset_indexes:
@@ -141,14 +138,6 @@ def channel_building(variable_id: VariableId, channel_output_dir_path: str,
         hu.write_ndarray_to_hdf5(dataset_data_file_path, dataset_data)
         du.save_to_csv_file(dataset_metadata, dataset_metadata_file_path, assembly.PANDAS_CSV_WRITE_OPTS)
 
-    # Cast into 64 bits otherwise the value is trunked.
-    min = float(channel_data.min())
-    max = float(channel_data.max())
-    stat_data = [{TensorDimension.MIN: min, TensorDimension.MAX: max, TensorDimension.MEAN: mean[0],
-                  TensorDimension.STD: scale[0]}]
-    stat_file_path = nu.compute_stat_file_path(variable_id, channel_output_dir_path)
-    cu.to_csv(data=stat_data, file_path=stat_file_path)
-
 
 def channel_stacking_batch(tensor_id: str,
                            extraction_conf_file_path: str,
