@@ -78,6 +78,9 @@ class ExtractionConfig(YamlSerializable):
         # At the end of the tensor assemble. Has it to be shuffled ?
         self.has_tensor_to_be_shuffled: bool = None
 
+        # Are the channels of the tensor at the last dimensions of the tensor ?
+        self.is_channels_last = None
+
         # The tensor will be split into the given dataset ratios.
         self.tensor_dataset_ratios: Mapping[str, float] = None
 
